import bpy

class CAMERA2VIEW_PT_Panel(bpy.types.Panel):
    bl_label = "Camera2View"
    bl_idname = "CAMERA2VIEW_PT_panel"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = 'Camera2View'

    def draw(self, context):
        layout = self.layout
        scene = context.scene
        cam = scene.camera

        layout.operator("camera2view.create_camera", icon='CAMERA_DATA')
        layout.operator("camera2view.keyframe_camera", icon='KEY_HLT')

        layout.separator()
        layout.label(text="Camera Navigation", icon='CAMERA_DATA')
        layout.operator("camera2view.next_camera", icon='TRIA_RIGHT')
        layout.operator("camera2view.prev_camera", icon='TRIA_LEFT')

        layout.separator()
        layout.label(text="Keyframe Navigation", icon='KEY_HLT')
        layout.operator("camera2view.next_keyframe", icon='TRIA_RIGHT')
        layout.operator("camera2view.prev_keyframe", icon='TRIA_LEFT')

        if cam and cam.type == 'CAMERA' and cam.name.startswith("Camera2View_"):
            cam_data = cam.data
            layout.separator()
            layout.label(text="Lens Properties", icon='OUTLINER_OB_CAMERA')

            def row_prop_key(prop, label):
                row = layout.row(align=True)
                row.prop(cam_data, prop, text=label)
                row.operator("camera2view.keyframe_property", text="Keyframe").property_name = prop

            row_prop_key("type", "Type")

            if cam_data.type == 'PERSP':
                row_prop_key("lens", "Focal Length")
                row_prop_key("lens_unit", "Lens Unit")
            elif cam_data.type == 'ORTHO':
                row_prop_key("ortho_scale", "Ortho Scale")

            row_prop_key("shift_x", "Shift X")
            row_prop_key("shift_y", "Shift Y")
            row_prop_key("clip_start", "Clip Start")
            row_prop_key("clip_end", "Clip End")

        # New section: Format Properties
        layout.separator()
        layout.label(text="Format Properties", icon='RENDER_RESULT')

        render = scene.render
        layout.prop(render, "resolution_x", text="Resolution X")
        layout.prop(render, "resolution_y", text="Resolution Y")
        layout.prop(render, "resolution_percentage", text="Scale (%)")
        layout.prop(render, "pixel_aspect_x", text="Pixel Aspect X")
        layout.prop(render, "pixel_aspect_y", text="Pixel Aspect Y")
        
        # New section: View Lock
        layout.separator()
        layout.label(text="View Lock", icon='LOCKED')

        area = next((a for a in context.window.screen.areas if a.type == 'VIEW_3D'), None)
        if area:
            space = next((s for s in area.spaces if s.type == 'VIEW_3D'), None)
            if space:
                layout.prop(space, "lock_object", text="Lock to Object")
                layout.prop(space, "use_cursor_lock", text="Lock to 3D Cursor")
                layout.prop(space, "lock_camera", text="Camera to View")
